==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TemplateCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescription } from "./TemplateCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateCellUpdatingEventArgsDescriptionMetadata.c(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(TemplateCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.ad("TemplateCellUpdatingEventArgs", function () { return new TemplateCellUpdatingEventArgsDescription(); });
        a.ac("TemplateCellUpdatingEventArgs", TemplateCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateCellUpdatingEventArgsDescriptionMetadata, 'TemplateCellUpdatingEventArgsDescriptionMetadata');
    TemplateCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateCellUpdatingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/TemplateCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescription } from "./TemplateCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateCellUpdatingEventArgsDescriptionMetadata.c(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(TemplateCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.ae("TemplateCellUpdatingEventArgs", function () { return new TemplateCellUpdatingEventArgsDescription(); });
        a.ad("TemplateCellUpdatingEventArgs", TemplateCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateCellUpdatingEventArgsDescriptionMetadata, 'TemplateCellUpdatingEventArgsDescriptionMetadata');
    TemplateCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateCellUpdatingEventArgsDescriptionMetadata };
